==> phoenix-tool-0.1.11-20240514.020519-1-sources.jar: com/elitesland/cbpl/tool/core/http/RestWrapper.java <==
package com.elitesland.cbpl.tool.core.http;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.extra.spring.SpringUtil;
import cn.hutool.http.HttpUtil;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.net.URI;
import java.nio.charset.StandardCharsets;
import java.util.Map;

/**
 * @author eric.hao
 * @since 2023/04/19
 */
@Component
public class RestWrapper {

    private static RestTemplate restTemplate;

    private static RestTemplate getInstance() {
        if (restTemplate == null) {
            restTemplate = SpringUtil.getBean(RestTemplate.class);
        }
        return restTemplate;
    }

    /**
     * get请求
     *
     * @param url    请求url
     * @param reqObj 请求request实体
     * @return 请求结果
     */
    public String get(String url, Map<String, Object> reqObj) {
        return get(url, reqObj, null);
    }

    /**
     * get请求
     *
     * @param url        请求url
     * @param reqObj     请求request实体
     * @param addHeaders 添加的头部 如需要使用jwt，key名称需设为"Bearer-Auth"
     * @return 请求结果
     */
    public String get(String url, Map<String, Object> reqObj, Map<String, String> addHeaders) {
        String queryParams = HttpUtil.toParams(reqObj, StandardCharsets.UTF_8);
        String requestUrl = url + "?" + queryParams;
        HttpEntity<String> entity = getMethodHttpEntity(addHeaders);
        return getInstance().exchange(URI.create(requestUrl), HttpMethod.GET, entity, String.class).getBody();
    }

    /**
     * form-data的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @return 请求结果
     */
    public String postFormData(String requestUrl, Map<String, Object> reqObj) {
        return postFormData(requestUrl, reqObj, null);
    }

    /**
     * form-data的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @param addHeaders 添加的头部 如需要使用jwt,key名称需设为"Bearer-Auth"
     * @return 请求结果
     */
    public String postFormData(String requestUrl, Map<String, Object> reqObj, Map<String, String> addHeaders) {
        HttpEntity<MultiValueMap<String, Object>> entity = getFormRequestHttpEntity(reqObj, MediaType.MULTIPART_FORM_DATA_VALUE, addHeaders);
        return getInstance().postForObject(requestUrl, entity, String.class);
    }

    /**
     * x-www-form-urlencoded的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @return 请求结果
     */
    public String postFormUrlencoded(String requestUrl, Map<String, Object> reqObj) {
        return postFormUrlencoded(requestUrl, reqObj, null);
    }

    /**
     * x-www-form-urlencoded的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @param addHeaders 添加的头部 如需要使用jwt,key名称需设为"Bearer-Auth"
     * @return 请求结果
     */
    public String postFormUrlencoded(String requestUrl, Map<String, Object> reqObj, Map<String, String> addHeaders) {
        HttpEntity<MultiValueMap<String, Object>> entity = getFormRequestHttpEntity(reqObj, MediaType.APPLICATION_FORM_URLENCODED_VALUE, addHeaders);
        return getInstance().postForObject(requestUrl, entity, String.class);
    }

    /**
     * json的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @return 请求结果
     */
    public String postJsonData(String requestUrl, Map<String, Object> reqObj) {
        return postJsonData(requestUrl, reqObj, null);
    }

    /**
     * json的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @param addHeaders 添加的头部 如需要使用jwt,key名称需设为"Bearer-Auth"
     * @return 请求结果
     */
    public String postJsonData(String requestUrl, Object reqObj, Map<String, String> addHeaders) {
        HttpEntity<?> entity = getJsonRequestHttpEntity(reqObj, addHeaders);
        return getInstance().exchange(requestUrl, HttpMethod.POST, entity, String.class).getBody();
    }

    /**
     * 请求request实体转form-data的map
     *
     * @param reqObj 请求request实体
     * @return 请求参数
     */
    public MultiValueMap<String, Object> requestBeanToFormParams(Map<String, Object> reqObj) {
        MultiValueMap<String, Object> multiValueMap = new LinkedMultiValueMap<>();
        for (String key : reqObj.keySet()) {
            multiValueMap.add(key, reqObj.get(key));
        }
        return multiValueMap;
    }

    /**
     * 获取get方法的HttpEntity
     *
     * @param addHeaders 添加的头部
     * @return 请求参数
     */
    public HttpEntity<String> getMethodHttpEntity(Map<String, String> addHeaders) {
        HttpHeaders headers = getHttpHeaders(MediaType.APPLICATION_JSON);
        addHeaders(headers, addHeaders);
        return new HttpEntity<>(null, headers);
    }

    /**
     * 获取form请求的HttpEntity
     *
     * @param reqObj      请求request实体
     * @param contentType form请求类型
     * @param addHeaders  添加的头部
     * @return 构建参数体
     */
    public HttpEntity<MultiValueMap<String, Object>> getFormRequestHttpEntity(Map<String, Object> reqObj, String contentType, Map<String, String> addHeaders) {
        HttpHeaders headers = null;
        if (MediaType.APPLICATION_FORM_URLENCODED_VALUE.equals(contentType)) {
            headers = getHttpHeaders(MediaType.APPLICATION_FORM_URLENCODED);
        } else if (MediaType.MULTIPART_FORM_DATA_VALUE.equals(contentType)) {
            headers = getHttpHeaders(MediaType.MULTIPART_FORM_DATA);
        }
        addHeaders(headers, addHeaders);
        MultiValueMap<String, Object> multiValueMap = requestBeanToFormParams(reqObj);
        return new HttpEntity<>(multiValueMap, headers);
    }

    /**
     * 获取json请求的HttpEntity
     *
     * @param obj        请求request实体
     * @param addHeaders 添加的头部
     * @return 请求参数
     */
    public HttpEntity<?> getJsonRequestHttpEntity(Object obj, Map<String, String> addHeaders) {
        HttpHeaders headers = getHttpHeaders(MediaType.APPLICATION_JSON);
        addHeaders(headers, addHeaders);
        return new HttpEntity<>(obj, headers);
    }

    /**
     * 获取指定mediaType请求头
     */
    public HttpHeaders getHttpHeaders(MediaType mediaType) {
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(mediaType);
        return headers;
    }

    /**
     * 添加自定义的头部
     *
     * @param headers    头部参数
     * @param addHeaders 自定义参数
     */
    public void addHeaders(HttpHeaders headers, Map<String, String> addHeaders) {
        if (ObjectUtil.isEmpty(addHeaders)) {
            return;
        }
        for (String key : addHeaders.keySet()) {
            // jwt授权
            if ("Bearer-Auth".equals(key)) {
                headers.setBearerAuth(addHeaders.get(key));
                continue;
            }
            headers.set(key, addHeaders.get(key));
        }
    }
}

==> phoenix-tool-0.1.18.7-20250103.014925-2-sources.jar: com/elitesland/cbpl/tool/core/http/RestWrapper.java <==
package com.elitesland.cbpl.tool.core.http;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.http.HttpUtil;
import com.elitesland.cbpl.tool.extra.spring.SpringUtils;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.net.URI;
import java.nio.charset.StandardCharsets;
import java.util.Map;

/**
 * @author eric.hao
 * @since 2023/04/19
 */
@Component
public class RestWrapper {

    private static RestTemplate restTemplate;

    /**
     * 获取`BeanName=phoenixRestTemplate`的`RestTemplate`
     *
     * @since 0.1.13-SNAPSHOT
     */
    private static RestTemplate getInstance() {
        if (restTemplate == null) {
            restTemplate = SpringUtils.getBean("phoenixRestTemplate");
        }
        return restTemplate;
    }

    /**
     * get请求
     *
     * @param url    请求url
     * @param reqObj 请求request实体
     * @return 请求结果
     */
    public String get(String url, Map<String, Object> reqObj) {
        return get(url, reqObj, null);
    }

    /**
     * get请求
     *
     * @param url        请求url
     * @param reqObj     请求request实体
     * @param addHeaders 添加的头部 如需要使用jwt，key名称需设为"Bearer-Auth"
     * @return 请求结果
     */
    public String get(String url, Map<String, Object> reqObj, Map<String, String> addHeaders) {
        String queryParams = HttpUtil.toParams(reqObj, StandardCharsets.UTF_8);
        String requestUrl = url + "?" + queryParams;
        HttpEntity<String> entity = getMethodHttpEntity(addHeaders);
        return getInstance().exchange(URI.create(requestUrl), HttpMethod.GET, entity, String.class).getBody();
    }

    /**
     * form-data的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @return 请求结果
     */
    public String postFormData(String requestUrl, Map<String, Object> reqObj) {
        return postFormData(requestUrl, reqObj, null);
    }

    /**
     * form-data的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @param addHeaders 添加的头部 如需要使用jwt,key名称需设为"Bearer-Auth"
     * @return 请求结果
     */
    public String postFormData(String requestUrl, Map<String, Object> reqObj, Map<String, String> addHeaders) {
        HttpEntity<MultiValueMap<String, Object>> entity = getFormRequestHttpEntity(reqObj, MediaType.MULTIPART_FORM_DATA_VALUE, addHeaders);
        return getInstance().postForObject(requestUrl, entity, String.class);
    }

    /**
     * x-www-form-urlencoded的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @return 请求结果
     */
    public String postFormUrlencoded(String requestUrl, Map<String, Object> reqObj) {
        return postFormUrlencoded(requestUrl, reqObj, null);
    }

    /**
     * x-www-form-urlencoded的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @param addHeaders 添加的头部 如需要使用jwt,key名称需设为"Bearer-Auth"
     * @return 请求结果
     */
    public String postFormUrlencoded(String requestUrl, Map<String, Object> reqObj, Map<String, String> addHeaders) {
        HttpEntity<MultiValueMap<String, Object>> entity = getFormRequestHttpEntity(reqObj, MediaType.APPLICATION_FORM_URLENCODED_VALUE, addHeaders);
        return getInstance().postForObject(requestUrl, entity, String.class);
    }

    /**
     * json的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @return 请求结果
     */
    public String postJsonData(String requestUrl, Map<String, Object> reqObj) {
        return postJsonData(requestUrl, reqObj, null);
    }

    /**
     * json的post请求
     *
     * @param requestUrl 请求url
     * @param reqObj     请求request实体
     * @param addHeaders 添加的头部 如需要使用jwt,key名称需设为"Bearer-Auth"
     * @return 请求结果
     */
    public String postJsonData(String requestUrl, Object reqObj, Map<String, String> addHeaders) {
        HttpEntity<?> entity = getJsonRequestHttpEntity(reqObj, addHeaders);
        return getInstance().exchange(requestUrl, HttpMethod.POST, entity, String.class).getBody();
    }

    /**
     * 请求request实体转form-data的map
     *
     * @param reqObj 请求request实体
     * @return 请求参数
     */
    public MultiValueMap<String, Object> requestBeanToFormParams(Map<String, Object> reqObj) {
        MultiValueMap<String, Object> multiValueMap = new LinkedMultiValueMap<>();
        for (String key : reqObj.keySet()) {
            multiValueMap.add(key, reqObj.get(key));
        }
        return multiValueMap;
    }

    /**
     * 获取get方法的HttpEntity
     *
     * @param addHeaders 添加的头部
     * @return 请求参数
     */
    public HttpEntity<String> getMethodHttpEntity(Map<String, String> addHeaders) {
        HttpHeaders headers = getHttpHeaders(MediaType.APPLICATION_JSON);
        addHeaders(headers, addHeaders);
        return new HttpEntity<>(null, headers);
    }

    /**
     * 获取form请求的HttpEntity
     *
     * @param reqObj      请求request实体
     * @param contentType form请求类型
     * @param addHeaders  添加的头部
     * @return 构建参数体
     */
    public HttpEntity<MultiValueMap<String, Object>> getFormRequestHttpEntity(Map<String, Object> reqObj, String contentType, Map<String, String> addHeaders) {
        HttpHeaders headers = null;
        if (MediaType.APPLICATION_FORM_URLENCODED_VALUE.equals(contentType)) {
            headers = getHttpHeaders(MediaType.APPLICATION_FORM_URLENCODED);
        } else if (MediaType.MULTIPART_FORM_DATA_VALUE.equals(contentType)) {
            headers = getHttpHeaders(MediaType.MULTIPART_FORM_DATA);
        }
        addHeaders(headers, addHeaders);
        MultiValueMap<String, Object> multiValueMap = requestBeanToFormParams(reqObj);
        return new HttpEntity<>(multiValueMap, headers);
    }

    /**
     * 获取json请求的HttpEntity
     *
     * @param obj        请求request实体
     * @param addHeaders 添加的头部
     * @return 请求参数
     */
    public HttpEntity<?> getJsonRequestHttpEntity(Object obj, Map<String, String> addHeaders) {
        HttpHeaders headers = getHttpHeaders(MediaType.APPLICATION_JSON);
        addHeaders(headers, addHeaders);
        return new HttpEntity<>(obj, headers);
    }

    /**
     * 获取指定mediaType请求头
     */
    public HttpHeaders getHttpHeaders(MediaType mediaType) {
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(mediaType);
        return headers;
    }

    /**
     * 添加自定义的头部
     *
     * @param headers    头部参数
     * @param addHeaders 自定义参数
     */
    public void addHeaders(HttpHeaders headers, Map<String, String> addHeaders) {
        if (ObjectUtil.isEmpty(addHeaders)) {
            return;
        }
        for (String key : addHeaders.keySet()) {
            // jwt授权
            if ("Bearer-Auth".equals(key)) {
                headers.setBearerAuth(addHeaders.get(key));
                continue;
            }
            headers.set(key, addHeaders.get(key));
        }
    }
}
